import requests
import requests_cache
from collections import OrderedDict
from datetime import datetime
from dateutil import parser
from operator import itemgetter
from tabulate import tabulate

SCHEDULE_URL = "http://pyohio.org/schedule/json/"

def get_schedule(cache_ttl=3600):
    """ Get the schedule from the conference website and return the JSON. """
    requests_cache.install_cache(expire_after=cache_ttl)
    response = requests.get(SCHEDULE_URL)
    response.raise_for_status()
    return response.json()

def _session_summary(session):
    """ Given a detailed session dict, return a summary dict. """
    summary = OrderedDict()
    summary['date'] = parser.parse(session.get('start', '2016')).date().isoformat()
    summary['start_time'] = parser.parse(session.get('start', '2016')).time().strftime('%H:%M')
    summary['end_time'] = parser.parse(session.get('end', '2016')).time().strftime('%H:%M')
    summary['room'] = session.get('room')
    summary['name'] = session.get('name')
    authors = session.get('authors', []) or []
    summary['presenter'] = ", ".join(authors)
    return summary

def make_table(schedule, start_datetime=None):
    """ Given a list of session summaries, return a simple text table. """
    if start_datetime is None:
        start_datetime = datetime(1900, 1, 1)
    schedule_summary = [_session_summary(session) for session in schedule if \
            parser.parse(session.get('start', '2016')) > start_datetime]
    schedule_summary.sort(key=itemgetter('date', 'start_time', 'end_time'))
    return tabulate(schedule_summary, tablefmt="plain")



import click
import dateutil
from datetime import datetime
from pyohio import schedule

@click.group()
@click.option('--verbose', '-v', count=True)
@click.pass_context
def pyohio_cli(ctx, verbose):
    """PyOhio-related tools."""
    ctx.obj = {'verbose': verbose}

@pyohio_cli.command(name='schedule')
@click.option('--remaining', '-r', is_flag=True,
        help='Only sessions that have yet to start')
@click.option('--after',
        help='Only sessions starting after (ex: "2016-07-30 13:30")')
@click.pass_context
def pyohio_schedule(ctx, remaining, after):
    """Output the PyOhio schedule."""

    log('Downloading schedule...')
    schedule_json = schedule.get_schedule()
    if remaining and not after:
        start = datetime.now()
        log('Only returning sessions that have yet to start.')
    elif after:
        start = dateutil.parser.parse(after)
        log('Only returning sessions starting after {0}.'.format(start.isoformat()))
    else:
        start = None

    table_text = schedule.make_table(schedule_json, start_datetime=start)
    click.echo(table_text)

@click.pass_context
def log(ctx, message, verbosity=1):
    """ Output message to stderr if context verbosity >= passed verbosity.

    You'd typically want to incorporate this with a 'real' logger but this is
    good enough for our example.
    """
    verbose_count = ctx.obj.get('verbose')
    if verbose_count >= verbosity:
        click.echo(message, err=True)

if __name__ == '__main__':
    pyohio_cli()



"""A setuptools based setup module for pyohio"""
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from codecs import open
from os import path
from setuptools import setup, find_packages

import versioneer

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'HISTORY.rst'), encoding='utf-8') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

requirements = [
    'click',
    'colorama',
    'python-dateutil',
    'requests',
    'requests-cache',
    'tabulate',
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='pyohio',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="PyOhio-related tools.",
    long_description=readme + '\n\n' + history,
    author="Dave Forgac",
    author_email='tylerdave@tylerdave.com',
    url='https://github.com/tylerdave/pyohio',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    entry_points={
        'console_scripts':[
            'pyohio=pyohio.cli:pyohio_cli',
            ],
        },
    include_package_data=True,
    install_requires=requirements,
    license="MIT",
    keywords='pyohio',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_pyohio
----------------------------------

Tests for `pyohio` module.
"""

import unittest

import pyohio


class TestPyohio(unittest.TestCase):

    def setUp(self):
        pass

    def test_something(self):
        assert(pyohio.hello_world())
        pass

    def tearDown(self):
        pass
